function loglik = computeLoglik(Y, a, b, choiceModel)
    % compute the normalized loglik
    % Input parameters:
    % Y: the coordinates in the transformed space
    % a, b: the number of incorrect/correct choices. a_ij + b_ij == 0 means
    % the data is not available
    % choiceModel: a function handle for the choice model confusion probability = \psi(d)
    
    % only count for the pairs with a+b ~= 0
    I = find(a+b~=0);
    a = a(I);
    b = b(I);
    d = squareform(pdist(Y'));
    d = d(I);
    [p logP] = feval(choiceModel, d); 
    loglik = mean(((a.* logP + b.*log(1 - p))./(a+b)));
    
