function x = inverseMapping(W, X, y, kernel)
    % Given coordinates in original space, compute the coordinates in
    % transformed space.
    % ***************************************
    % Input Parameters:
    % ***************************************
    % y: d_h-by-1 vector, the coordinates of some objects in the transformed space
    % W: the weight vector learned by yada_learn;
    % X: The coordinates of objects used in input of yada_learn.
    % kernel: kernel parameters used in yada_learn, which is a structure.
    % Currently, only RBF kernel is supported. So kernel.type = 'rbf' and
    % kernel.sigma should be specified. The output of yada_learn.
    % ***************************************
    % Output Parameters:
    % ***************************************
    % x: d_r-by-1 vector, the coordinates of y in raw physical space
    
    % Initialization
    
    % create a grid
    d_r = size(X, 1);
    if (d_r == 1)
        x_grid = -1:0.05:1;
    else
        x_grid = zeros(d_r, 11^d_r);
        siz = 11 * ones(1, d_r);
        for i=1:d_r,
            t = (-1:0.2:1)'; % Extract and reshape as a vector.
            s = siz; s(i) = []; % Remove i-th dimension
            t = reshape(t(:,ones(1,prod(s))),[length(t) s]); % Expand x
            t = permute(t,[2:i 1 i+1:d_r]); % Permute to i'th dimension
            x_grid(i,:) = t(:)';
        end
    end
    
    K = Kx(X, x_grid, kernel);
    y_grid = W * K;
%     d = sum((y_grid - 2 * repmat(y, 1, size(y_grid, 2)))' * y_grid);
    ydiff = y_grid - repmat(y, 1, size(y_grid, 2));
    d = diag(ydiff'*ydiff);
    [~, idx] = min(d);
    x_t = x_grid(:,idx);
    
    func = @(x)obj_inverse(W, X, x, y, kernel);
    options = optimset('GradObj', 'on', 'LargeScale', 'off', 'Display', 'off');
    x = fminunc(func, x_t, options);