function [W  runtime fval] = learnMapping(X, a, b, choiceModel, params)
    % solve the optimization problem in term of W
    % gradient descent with initialization with w0 = argmin \|w0*K - X\|_F^2
    % Input parameters:
    % X: the coordinates in raw space
    % a,b : the correct and incorrect number of response in XAB experiment
    % choideModel: a function handle for the choice model confusion probability = \psi(d)
    % params: params.mu the wight of regularizer
    %         params.kernel: kernel parameters
    %         params.dh: the dimension of perceptual space
    %         params.Gradients: 'on' or 'off', provide gradient information in
    %         choice model to the algorithm or not.
    % Output Parameters:
    % W: the weight vector learned
    % runtime: the time it takes for learning the mapping
    % fval: the objective function value
    
    T0 = cputime;
    
    if (params.d_h == size(X, 1))
        xtmp = X;
    else if (params.d_h < size(X, 1))
            % if the dimensionality of raw parameter space is not equal to the
            % one in perceptual space, run PCA
            [v r] = eigs(X'*X, params.d_h);
            xtmp = sqrt(r) * v';
        else
            xtmp = [X; ones(params.d_h - size(X,1), size(X, 2))];
        end
    end;
    
    c = maxLoglikByLineSearch(xtmp, a, b, choiceModel);
    K = Kx(X, X, params.kernel);
    w0 = c * (xtmp * K')/(params.mu * K  + K * K');
    
    options = optimset('GradObj', params.GradOn, 'MaxIter', 700,  'Display', 'off', 'LargeScale', 'off');
    func = @(W)obj(params.mu, W, K, a, b, choiceModel);
    [W, fval] = fminunc(func, w0, options);
    
    runtime = cputime - T0;
    