function y = yada_map(x, W, X, kernel)
    %
    % y = yada_map(x, W, X, kernel)
    %
    % Given coordinates in original space, compute the coordinates in
    % transformed space.
    % ***************************************
    % Input Parameters:
    % ***************************************
    % x: d_r-by-n matrix, the coordinates of objects in raw physical space
    % W: the weight vector learned by yada_learn;
    % X: The coordinates of objects used in input of yada_learn.
    % kernel: kernel parameters used in yada_learn, which is a structure.
    % Currently, only RBF kernel is supported. So kernel.type = 'rbf' and
    % kernel.sigma should be specified. The output of yada_learn.
    % ***************************************
    % Output Parameters:
    % ***************************************
    % y: d_h-by-n matrix, the coordinates of x in the transformed space
    
    x = (x - repmat(mean(X, 2), 1, size(x, 2))) ./ repmat(std(X, 0, 2), 1, size(x, 2));
    X = (X - repmat(mean(X, 2), 1, size(X, 2))) ./ repmat(std(X, 0, 2), 1, size(X, 2));
    K = Kx(X, x, kernel);
    y = W * K;